@@ -20,6 +20,10 @@ void
 on_b_ok3_clicked                        (GtkButton       *button,
                                         gpointer         user_data);
 
+void
+on_b_ok4_clicked                        (GtkButton       *button,
+                                        gpointer         user_data);
+
 void
 on_b_close_clicked                        (GtkButton       *button,
                                         gpointer         user_data);
@@ -36,6 +40,13 @@ void
 on_file_browse3_clicked                        (GtkButton       *button,
                                         gpointer         user_data);
 
+void
+on_file_browse4_clicked                        (GtkButton       *button,
+                                        gpointer         user_data);
+
+// NES Sound toggle clicked
+void on_cb_sound2_clicked(GtkToggleButton *button, gpointer user_data);
+
 gboolean
 on_mainwindow_destroy_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
