@@ -6,6 +6,7 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 
+#include "util.h"
 #include "xmame.h"
 
 
@@ -19,18 +20,24 @@
 gint launch_xmame(const gchar *romname, gboolean use_sound, gboolean fullscreen, gboolean ror, gboolean scale){
 	int	status = 0,
 		pid = 0;
+	char *fullrom = get_rom_full_path(romname,XMAEME_ROMTYPE_MAME);
+
+	if(!fullrom){
+		fullrom = g_strdup(romname);
+	}//use base romname
+
 
 	if((pid=fork())){
 		waitpid(pid, &status, 0);
 	}//parent
 	else{
 		int i = 2;
-		char* args[8] = { XMAEME_XMAME_EXE, (char*)romname, NULL, NULL, NULL, NULL, NULL, NULL };
+		char* args[8] = { XMAEME_XMAME_EXE, fullrom, NULL, NULL, NULL, NULL, NULL, NULL };
 
 		if(!use_sound)
 			args[i++] = XMAEME_NO_SOUND;
-		if(fullscreen)
-			args[i++] = XMAEME_FULLSCREEN;
+		//if(fullscreen)
+		args[i++] = XMAEME_FULLSCREEN;
 		if(ror)
 			args[i++] = XMAEME_ROR;
 		if(scale){
@@ -56,5 +63,7 @@ gint launch_xmame(const gchar *romname, gboolean use_sound, gboolean fullscreen,
 		exit(0);
 	}//child
 
+	g_free(fullrom);
+
 	return status;
 }//launch_xmame
